# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_ema.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_ema.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xb7\x02\n\x12IntradayEmaRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x16\n\x06length\x18\x04 \x01(\x05R\x06length\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"l\n\x13IntradayEmaResponse\x12U\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayEmaDataR\x04\x64\x61ta\"|\n\x0fIntradayEmaData\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x18\n\x07\x61verage\x18\x03 \x01(\x01R\x07\x61verage2\xcb\x01\n\x12IntradayEmaService\x12\xb4\x01\n\x0bIntradayEma\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayEmaRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayEmaResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/intraday/emab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday_analytics.v1.intraday_ema_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INTRADAYEMASERVICE'].methods_by_name['IntradayEma']._options = None
  _globals['_INTRADAYEMASERVICE'].methods_by_name['IntradayEma']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/intraday/ema'
  _globals['_INTRADAYEMAREQUEST']._serialized_start=339
  _globals['_INTRADAYEMAREQUEST']._serialized_end=650
  _globals['_INTRADAYEMARESPONSE']._serialized_start=652
  _globals['_INTRADAYEMARESPONSE']._serialized_end=760
  _globals['_INTRADAYEMADATA']._serialized_start=762
  _globals['_INTRADAYEMADATA']._serialized_end=886
  _globals['_INTRADAYEMASERVICE']._serialized_start=889
  _globals['_INTRADAYEMASERVICE']._serialized_end=1092
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/calendar/v1/calendar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/calendar/v1/calendar.proto\x12&systemathics.apis.services.calendar.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xca\x01\n\x0bHolidayInfo\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07\x63ountry\x18\x02 \x01(\tR\x07\x63ountry\x12\x1a\n\x08\x63urrency\x18\x03 \x01(\tR\x08\x63urrency\x12G\n\x04type\x18\x04 \x01(\x0e\x32\x33.systemathics.apis.services.calendar.v1.HolidayTypeR\x04type\x12\x12\n\x04mics\x18\x05 \x03(\tR\x04mics\x12\x14\n\x05years\x18\x06 \x03(\x05R\x05years\"p\n\x19HolidayCodeToMicsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32=.systemathics.apis.services.calendar.v1.HolidayCodeToMicsItemR\x05items\"N\n\x15HolidayCodeToMicsItem\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12\x12\n\x04mics\x18\x02 \x03(\tR\x04mics\"J\n\x17TradingHoursDateRequest\x12/\n\x04year\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x04year\"d\n\x18TradingHoursDateResponse\x12\x12\n\x04year\x18\x01 \x01(\x05R\x04year\x12\x34\n\x0ctrading_days\x18\x02 \x03(\x0b\x32\x11.google.type.DateR\x0btradingDays\"e\n\x0fHolidaysRequest\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12/\n\x04year\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x04year\"}\n\x10HolidaysResponse\x12!\n\x0choliday_code\x18\x01 \x01(\tR\x0bholidayCode\x12\x12\n\x04year\x18\x02 \x01(\x05R\x04year\x12\x32\n\x0b\x63losed_days\x18\x03 \x03(\x0b\x32\x11.google.type.DateR\nclosedDays\"-\n\x17TradingHoursMicResponse\x12\x12\n\x04mics\x18\x01 \x03(\tR\x04mics\"Y\n\x13TradingHoursRequest\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12\x30\n\ntrade_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\ttradeDate\"\xc9\n\n\tMicRecord\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12T\n\x08mic_type\x18\x02 \x01(\x0e\x32\x39.systemathics.apis.services.calendar.v1.MicRecord.MicTypeR\x07micType\x12#\n\roperating_mic\x18\x03 \x01(\tR\x0coperatingMic\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12*\n\x11legal_entity_name\x18\x05 \x01(\tR\x0flegalEntityName\x12\x36\n\x17legal_entity_identifier\x18\x06 \x01(\tR\x15legalEntityIdentifier\x12p\n\x14market_category_code\x18\x07 \x01(\x0e\x32>.systemathics.apis.services.calendar.v1.MicRecord.CategoryCodeR\x12marketCategoryCode\x12\x36\n\x07\x61\x63ronym\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x61\x63ronym\x12(\n\x10iso_country_code\x18\t \x01(\tR\x0eisoCountryCode\x12\x12\n\x04\x63ity\x18\n \x01(\tR\x04\x63ity\x12\x36\n\x07website\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07website\x12S\n\x06status\x18\x0c \x01(\x0e\x32;.systemathics.apis.services.calendar.v1.MicRecord.MicStatusR\x06status\x12\x36\n\rcreation_date\x18\r \x01(\x0b\x32\x11.google.type.DateR\x0c\x63reationDate\x12;\n\x10last_update_date\x18\x0e \x01(\x0b\x32\x11.google.type.DateR\x0elastUpdateDate\x12\x43\n\x14last_validation_date\x18\x0f \x01(\x0b\x32\x11.google.type.DateR\x12lastValidationDate\x12\x32\n\x0b\x65xpiry_date\x18\x10 \x01(\x0b\x32\x11.google.type.DateR\nexpiryDate\x12\x36\n\x07\x63omment\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x63omment\x12\x1b\n\ttime_zone\x18\x12 \x01(\tR\x08timeZone\"P\n\x07MicType\x12\x18\n\x14MIC_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MIC_TYPE_OPERATOR\x10\x01\x12\x14\n\x10MIC_TYPE_SEGMENT\x10\x02\"\xae\x01\n\x0c\x43\x61tegoryCode\x12\x08\n\x04NSPD\x10\x00\x12\x08\n\x04\x41TSS\x10\x01\x12\x08\n\x04\x41PPA\x10\x02\x12\x08\n\x04\x41RMS\x10\x03\x12\x08\n\x04\x43TPS\x10\x04\x12\x08\n\x04\x43\x41SP\x10\x05\x12\x08\n\x04\x44\x43MS\x10\x06\x12\x08\n\x04IDQS\x10\x07\x12\x08\n\x04MLTF\x10\x08\x12\x08\n\x04OTFS\x10\t\x12\x08\n\x04OTHR\x10\n\x12\x08\n\x04RMOS\x10\x0b\x12\x08\n\x04RMKT\x10\x0c\x12\x08\n\x04SEFS\x10\r\x12\x08\n\x04SINT\x10\x0e\x12\x08\n\x04TRFS\x10\x0f\"n\n\tMicStatus\x12\x1a\n\x16MIC_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11MIC_STATUS_ACTIVE\x10\x01\x12\x16\n\x12MIC_STATUS_EXPIRED\x10\x02\x12\x16\n\x12MIC_STATUS_UPDATED\x10\x03\"\xe0\x02\n\x13TradingHoursMessage\x12\x10\n\x03mic\x18\x01 \x01(\tR\x03mic\x12\x30\n\ntrade_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\ttradeDate\x12=\n\x0eorder_accepted\x18\x03 \x01(\x0b\x32\x16.google.type.TimeOfDayR\rorderAccepted\x12\x35\n\nearly_open\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDayR\tearlyOpen\x12*\n\x04open\x18\x05 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x06 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x35\n\nlate_close\x18\x07 \x01(\x0b\x32\x16.google.type.TimeOfDayR\tlateClose*v\n\x0bHolidayType\x12\x1c\n\x18HOLIDAY_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cHOLIDAY_TYPE_FUTURES_TRADING\x10\x01\x12\'\n#HOLIDAY_TYPE_STOCK_EXCHANGE_TRADING\x10\x02\x32\xc2\x08\n\x0f\x43\x61lendarService\x12~\n\x0eGetHolidayCode\x12\x16.google.protobuf.Empty\x1a\x33.systemathics.apis.services.calendar.v1.HolidayInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/calendar/holidays0\x01\x12\x98\x01\n\x11HolidayCodeToMics\x12\x16.google.protobuf.Empty\x1a\x41.systemathics.apis.services.calendar.v1.HolidayCodeToMicsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/holiday_code_2_mics\x12\x9c\x01\n\x08Holidays\x12\x37.systemathics.apis.services.calendar.v1.HolidaysRequest\x1a\x38.systemathics.apis.services.calendar.v1.HolidaysResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/calendar/holidays\x12\x93\x01\n\x0fTradingHoursMic\x12\x16.google.protobuf.Empty\x1a?.systemathics.apis.services.calendar.v1.TradingHoursMicResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/calendar/trading_hours/mics\x12\xc0\x01\n\x11TradingHoursDates\x12?.systemathics.apis.services.calendar.v1.TradingHoursDateRequest\x1a@.systemathics.apis.services.calendar.v1.TradingHoursDateResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/calendar/trading_hours/dates\x12m\n\x03Mic\x12\x16.google.protobuf.Empty\x1a\x31.systemathics.apis.services.calendar.v1.MicRecord\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/calendar/mics0\x01\x12\xac\x01\n\x0cTradingHours\x12;.systemathics.apis.services.calendar.v1.TradingHoursRequest\x1a;.systemathics.apis.services.calendar.v1.TradingHoursMessage\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/calendar/trading_hoursb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.calendar.v1.calendar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['GetHolidayCode']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['GetHolidayCode']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/calendar/holidays'
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCodeToMics']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['HolidayCodeToMics']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/holiday_code_2_mics'
  _globals['_CALENDARSERVICE'].methods_by_name['Holidays']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['Holidays']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/calendar/holidays'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursMic']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursMic']._serialized_options = b'\202\323\344\223\002!\022\037/v1/calendar/trading_hours/mics'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursDates']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHoursDates']._serialized_options = b'\202\323\344\223\002\"\022 /v1/calendar/trading_hours/dates'
  _globals['_CALENDARSERVICE'].methods_by_name['Mic']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['Mic']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/calendar/mics'
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHours']._options = None
  _globals['_CALENDARSERVICE'].methods_by_name['TradingHours']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/calendar/trading_hours'
  _globals['_HOLIDAYTYPE']._serialized_start=2897
  _globals['_HOLIDAYTYPE']._serialized_end=3015
  _globals['_HOLIDAYINFO']._serialized_start=242
  _globals['_HOLIDAYINFO']._serialized_end=444
  _globals['_HOLIDAYCODETOMICSRESPONSE']._serialized_start=446
  _globals['_HOLIDAYCODETOMICSRESPONSE']._serialized_end=558
  _globals['_HOLIDAYCODETOMICSITEM']._serialized_start=560
  _globals['_HOLIDAYCODETOMICSITEM']._serialized_end=638
  _globals['_TRADINGHOURSDATEREQUEST']._serialized_start=640
  _globals['_TRADINGHOURSDATEREQUEST']._serialized_end=714
  _globals['_TRADINGHOURSDATERESPONSE']._serialized_start=716
  _globals['_TRADINGHOURSDATERESPONSE']._serialized_end=816
  _globals['_HOLIDAYSREQUEST']._serialized_start=818
  _globals['_HOLIDAYSREQUEST']._serialized_end=919
  _globals['_HOLIDAYSRESPONSE']._serialized_start=921
  _globals['_HOLIDAYSRESPONSE']._serialized_end=1046
  _globals['_TRADINGHOURSMICRESPONSE']._serialized_start=1048
  _globals['_TRADINGHOURSMICRESPONSE']._serialized_end=1093
  _globals['_TRADINGHOURSREQUEST']._serialized_start=1095
  _globals['_TRADINGHOURSREQUEST']._serialized_end=1184
  _globals['_MICRECORD']._serialized_start=1187
  _globals['_MICRECORD']._serialized_end=2540
  _globals['_MICRECORD_MICTYPE']._serialized_start=2171
  _globals['_MICRECORD_MICTYPE']._serialized_end=2251
  _globals['_MICRECORD_CATEGORYCODE']._serialized_start=2254
  _globals['_MICRECORD_CATEGORYCODE']._serialized_end=2428
  _globals['_MICRECORD_MICSTATUS']._serialized_start=2430
  _globals['_MICRECORD_MICSTATUS']._serialized_end=2540
  _globals['_TRADINGHOURSMESSAGE']._serialized_start=2543
  _globals['_TRADINGHOURSMESSAGE']._serialized_end=2895
  _globals['_CALENDARSERVICE']._serialized_start=3018
  _globals['_CALENDARSERVICE']._serialized_end=4108
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xde\x0c\n\x17StaticDataSearchRequest\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x14\n\x05start\x18\x02 \x01(\x05R\x05start\x12\x14\n\x05\x63ount\x18\x03 \x01(\x05R\x05\x63ount\x12\x34\n\x06ticker\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06ticker\x12\x38\n\x08\x65xchange\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x65xchange\x12\x32\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x06\x61\x63tive\x12\x36\n\x07primary\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07primary\x12:\n\toperating\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\toperating\x12\x30\n\x04name\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04name\x12\x38\n\x08\x63urrency\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63urrency\x12\x36\n\x07\x63ountry\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x63ountry\x12:\n\tbloomberg\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tbloomberg\x12\x36\n\x07reuters\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07reuters\x12>\n\x0bmorningstar\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bmorningstar\x12\x34\n\x06markit\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06markit\x12\x30\n\x04\x66igi\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04\x66igi\x12\x43\n\x0e\x63omposite_figi\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rcompositeFigi\x12=\n\x0bshared_figi\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nsharedFigi\x12\x30\n\x04isin\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04isin\x12\x32\n\x05sedol\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sedol\x12\x38\n\x08\x63ontract\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63ontract\x12\x32\n\x05\x63usip\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x63usip\x12>\n\x0b\x64\x65scription\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scription\x12\x34\n\x06sector\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06sector\x12<\n\nunderlying\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nunderlying\x12U\n\x08maturity\x18\x1a \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.StaticDataDateR\x08maturity\x12`\n\x0e\x63\x61pitalization\x18\x1b \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.StaticDataIntR\x0e\x63\x61pitalization\x12.\n\x03\x63ik\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x03\x63ik\"\x9c\x01\n\x0eStaticDataDate\x12)\n\x05\x65xact\x18\x01 \x01(\x0b\x32\x11.google.type.DateH\x00R\x05\x65xact\x12V\n\x05range\x18\x02 \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeH\x00R\x05rangeB\x07\n\x05oneof\"\x8b\x01\n\x13StaticDataDateRange\x12.\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x08lessThan\x12\x44\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x12greaterOrEqualThan\"\x8d\x01\n\x10StaticDataDouble\x12\x16\n\x05\x65xact\x18\x01 \x01(\x01H\x00R\x05\x65xact\x12X\n\x05range\x18\x02 \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeH\x00R\x05rangeB\x07\n\x05oneof\"\xa3\x01\n\x15StaticDataDoubleRange\x12\x39\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08lessThan\x12O\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12greaterOrEqualThan\"\x87\x01\n\rStaticDataInt\x12\x16\n\x05\x65xact\x18\x01 \x01(\x03H\x00R\x05\x65xact\x12U\n\x05range\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.static_data.v1.StaticDataIntRangeH\x00R\x05rangeB\x07\n\x05oneof\"\x9e\x01\n\x12StaticDataIntRange\x12\x38\n\tless_than\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x08lessThan\x12N\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12greaterOrEqualThan\"\x8d\x02\n\x12StaticDataResponse\x12Q\n\x06\x66uture\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.FutureResponseR\x06\x66uture\x12Q\n\x06\x65quity\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.EquityResponseR\x06\x65quity\x12Q\n\x06\x63rypto\x18\x03 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.CryptoResponseR\x06\x63rypto\"\x81\x01\n\x0e\x43ryptoResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CryptoEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x45quityResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x46utureResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\xb8\x0b\n\x0b\x45quityEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x05 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x06 \x01(\tR\toperating\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x08 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\n \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\x0b \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0c \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\r \x01(\tR\x0b\x64\x65scription\x12*\n\x04open\x18\x0e \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x0f \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x10 \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x11 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x12 \x01(\x01R\npointValue\x12\x14\n\x05price\x18\x13 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x14 \x01(\x03R\x06volume\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12!\n\x0cmorning_star\x18\x19 \x01(\tR\x0bmorningStar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12%\n\x0e\x63omposite_figi\x18\x1c \x01(\tR\rcompositeFigi\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x10\n\x03\x63ik\x18! \x01(\tR\x03\x63ik\x12]\n\x07sectors\x18\" \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntryR\x07sectors\x12&\n\x0e\x63\x61pitalization\x18# \x01(\x03R\x0e\x63\x61pitalization\x12\x18\n\x07\x61\x64\x64ress\x18$ \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05phone\x18% \x01(\tR\x05phone\x12\x14\n\x05\x65mail\x18& \x01(\tR\x05\x65mail\x12\x10\n\x03url\x18\' \x01(\tR\x03url\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cSectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd5\x0b\n\x0b\x46utureEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x05 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x06 \x01(\tR\toperating\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x08 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\n \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\x0b \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0c \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\r \x01(\tR\x0b\x64\x65scription\x12*\n\x04open\x18\x0e \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x0f \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x10 \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x11 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x12 \x01(\x01R\npointValue\x12\x14\n\x05price\x18\x13 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x14 \x01(\x03R\x06volume\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12!\n\x0cmorning_star\x18\x19 \x01(\tR\x0bmorningStar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12%\n\x0e\x63omposite_figi\x18\x1c \x01(\tR\rcompositeFigi\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12\x1a\n\x08\x63ontract\x18\" \x01(\tR\x08\x63ontract\x12`\n\x08\x63\x61tegory\x18# \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntryR\x08\x63\x61tegory\x12\x14\n\x05\x63hain\x18$ \x01(\tR\x05\x63hain\x12-\n\x08maturity\x18% \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12\x14\n\x05month\x18& \x01(\tR\x05month\x12\x12\n\x04year\x18\' \x01(\x05R\x04year\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rCategoryEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa4\x0b\n\x0b\x43ryptoEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x05 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x06 \x01(\tR\toperating\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x08 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\n \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\x0b \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0c \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\r \x01(\tR\x0b\x64\x65scription\x12*\n\x04open\x18\x0e \x01(\x0b\x32\x16.google.type.TimeOfDayR\x04open\x12,\n\x05\x63lose\x18\x0f \x01(\x0b\x32\x16.google.type.TimeOfDayR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x10 \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x11 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x12 \x01(\x01R\npointValue\x12\x14\n\x05price\x18\x13 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x14 \x01(\x03R\x06volume\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.CryptoEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12!\n\x0cmorning_star\x18\x19 \x01(\tR\x0bmorningStar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12%\n\x0e\x63omposite_figi\x18\x1c \x01(\tR\rcompositeFigi\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x12\x1c\n\tconsensus\x18\" \x03(\tR\tconsensus\x12\x30\n\nissue_date\x18# \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12&\n\x0e\x63\x61pitalization\x18$ \x01(\x03R\x0e\x63\x61pitalization\x12-\n\x12\x63irculating_supply\x18% \x01(\x03R\x11\x63irculatingSupply\x12\x1d\n\nmax_supply\x18& \x01(\x03R\tmaxSupply\x12!\n\x0ctotal_supply\x18\' \x01(\x03R\x0btotalSupply\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"z\n\x15StaticDataIdentifiers\x12\x61\n\x0bidentifiers\x18\x01 \x03(\x0b\x32?.systemathics.apis.services.static_data.v1.StaticDataIdentifierR\x0bidentifiers\"\x8b\x01\n\x14StaticDataIdentifier\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\"4\n\x08TickSize\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x12\n\x04tick\x18\x02 \x01(\x01R\x04tick*\x86\x02\n\rFrequencyType\x12\x1e\n\x1a\x46REQUENCY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46REQUENCY_TYPE_NONE\x10\x01\x12\x16\n\x12\x46REQUENCY_TYPE_DAY\x10\x02\x12\x17\n\x13\x46REQUENCY_TYPE_WEEK\x10\x03\x12\x18\n\x14\x46REQUENCY_TYPE_MONTH\x10\x04\x12\x1a\n\x16\x46REQUENCY_TYPE_QUARTER\x10\x05\x12\x1d\n\x19\x46REQUENCY_TYPE_SEMIANNUAL\x10\x06\x12\x19\n\x15\x46REQUENCY_TYPE_ANNUAL\x10\x07\x12\x1b\n\x17\x46REQUENCY_TYPE_BIANNUAL\x10\x08*\x81\x01\n\x0c\x45xerciseType\x12\x1d\n\x19\x45XERCISE_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45XERCISE_TYPE_AMERICAN\x10\x01\x12\x1a\n\x16\x45XERCISE_TYPE_EUROPEAN\x10\x02\x12\x1a\n\x16\x45XERCISE_TYPE_BERMUDAN\x10\x03*\xed\x01\n\x0f\x43ouponFrequency\x12 \n\x1c\x43OUPON_FREQUENCY_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43OUPON_FREQUENCY_ANNUAL\x10\x01\x12 \n\x1c\x43OUPON_FREQUENCY_SEMI_ANNUAL\x10\x02\x12\x1d\n\x19\x43OUPON_FREQUENCY_QUATERLY\x10\x04\x12\x1f\n\x1b\x43OUPON_FREQUENCY_BI_MONTHLY\x10\x06\x12\x1c\n\x18\x43OUPON_FREQUENCY_MONTHLY\x10\x0c\x12\x1b\n\x17\x43OUPON_FREQUENCY_WEEKLY\x10\x34*\xe1\x10\n\x08\x44\x61yCount\x12\x19\n\x15\x44\x41Y_COUNT_UNSPECIFIED\x10\x00\x12\x15\n\x11\x44\x41Y_COUNT_ACT_ACT\x10\x01\x12\x15\n\x11\x44\x41Y_COUNT_ACT_360\x10\x02\x12\x15\n\x11\x44\x41Y_COUNT_ACT_365\x10\x03\x12\x14\n\x10\x44\x41Y_COUNT_30_ACT\x10\x04\x12\x14\n\x10\x44\x41Y_COUNT_30_360\x10\x05\x12\x14\n\x10\x44\x41Y_COUNT_30_365\x10\x06\x12\x14\n\x10\x44\x41Y_COUNT_NL_ACT\x10\x07\x12\x14\n\x10\x44\x41Y_COUNT_NL_360\x10\x08\x12\x14\n\x10\x44\x41Y_COUNT_NL_365\x10\t\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_ACT_NON_EOM\x10\n\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_360_NON_EOM\x10\x0b\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_365_NON_EOM\x10\x0c\x12\x1c\n\x18\x44\x41Y_COUNT_30_ACT_NON_EOM\x10\r\x12\x1c\n\x18\x44\x41Y_COUNT_30_360_NON_EOM\x10\x0e\x12\x1c\n\x18\x44\x41Y_COUNT_30_365_NON_EOM\x10\x0f\x12\x1c\n\x18\x44\x41Y_COUNT_NL_ACT_NON_EOM\x10\x10\x12\x1c\n\x18\x44\x41Y_COUNT_NL_360_NON_EOM\x10\x11\x12\x1c\n\x18\x44\x41Y_COUNT_NL_365_NON_EOM\x10\x12\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_ACT\x10\x13\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_360\x10\x14\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_365\x10\x15\x12 \n\x1c\x44\x41Y_COUNT_ISMA30_ACT_NON_EOM\x10\x16\x12 \n\x1c\x44\x41Y_COUNT_ISMA_30_360_NONEOM\x10\x17\x12 \n\x1c\x44\x41Y_COUNT_ISMA30_365_NON_EOM\x10\x18\x12\x15\n\x11\x44\x41Y_COUNT_ACT_364\x10\x1b\x12\x18\n\x14\x44\x41Y_COUNT_ACT_365_66\x10\x1c\x12\x1c\n\x18\x44\x41Y_COUNT_US_MUNI_30_360\x10\x1d\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_364_NON_EOM\x10\x1e\x12 \n\x1c\x44\x41Y_COUNT_MUNI30_360_NON_EOM\x10 \x12\x1a\n\x16\x44\x41Y_COUNT_BUS_DAYS_252\x10!\x12\x1b\n\x17\x44\x41Y_COUNT_GERMAN_30_360\x10#\x12 \n\x1c\x44\x41Y_COUNT_BUS_DAY_252NON_EOM\x10$\x12 \n\x1c\x44\x41Y_COUNT_ACT_365_66_NON_EOM\x10%\x12 \n\x1c\x44\x41Y_COUNT_GER_30_360_NON_EOM\x10&\x12\x1c\n\x18\x44\x41Y_COUNT_US_WIT_ACT_ACT\x10(\x12\x1c\n\x18\x44\x41Y_COUNT_US_WIB_ACT_360\x10)\x12\x1f\n\x1b\x44\x41Y_COUNT_ISDA_SWAPS_30_360\x10,\x12\x1f\n\x1b\x44\x41Y_COUNT_ISDA_SWAPS_30_365\x10-\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_360_NON_EOM\x10/\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_365_NON_EOM\x10\x30\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_ACT_NON_EOM\x10\x31\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_360\x10\x32\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_365\x10\x33\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_ACT\x10\x34\x12 \n\x1c\x44\x41Y_COUNT_ISDA_30E_360_N_EOM\x10\x35\x12 \n\x1c\x44\x41Y_COUNT_ISDA_30E_365_N_EOM\x10\x36\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_ACT_ACT\x10:\x12 \n\x1c\x44\x41Y_COUNT_ISDA_ACT_ACT_N_EOM\x10=\x12\x14\n\x10\x44\x41Y_COUNT_28_360\x10>\x12\x14\n\x10\x44\x41Y_COUNT_BD_252\x10\x63\x12\x19\n\x15\x44\x41Y_COUNT_ACT_ACT_101\x10\x65\x12\x19\n\x15\x44\x41Y_COUNT_ACT_360_102\x10\x66\x12\x19\n\x15\x44\x41Y_COUNT_ACT_365_103\x10g\x12\x18\n\x14\x44\x41Y_COUNT_30_360_104\x10h\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_ACT_NOM_105\x10i\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_360_NOM_106\x10j\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_365_NOM_107\x10k\x12\x1e\n\x19\x44\x41Y_COUNT_ISMA_30_360_131\x10\x83\x01\x12\x1f\n\x1a\x44\x41Y_COUNT_ISDA_ACT_ACT_201\x10\xc9\x01\x12\x1e\n\x19\x44\x41Y_COUNT_AFB_ACT_ACT_202\x10\xca\x01\x12#\n\x1e\x44\x41Y_COUNT_ISDA_ACT_ACT_NOM_203\x10\xcb\x01\x12\"\n\x1d\x44\x41Y_COUNT_AFB_ACT_ACT_NOM_204\x10\xcc\x01\x12 \n\x1b\x44\x41Y_COUNT_ISMA_ACT_ACT__206\x10\xce\x01\x12#\n\x1e\x44\x41Y_COUNT_ISMA_ACT_ACT_NOM_207\x10\xcf\x01\x12\x1b\n\x16\x44\x41Y_COUNT_BUSINESS_252\x10\xfc\x01\x12\x16\n\x11\x44\x41Y_COUNT_30E_360\x10\xde\x07\x12\x16\n\x11\x44\x41Y_COUNT_30E_365\x10\xdf\x07\x12\x16\n\x11\x44\x41Y_COUNT_30E_ACT\x10\xe0\x07\x12\x16\n\x11\x44\x41Y_COUNT_30G_360\x10\xe1\x07\x12\x16\n\x11\x44\x41Y_COUNT_301_360\x10\xe2\x07\x12\x16\n\x11\x44\x41Y_COUNT_301_365\x10\xe3\x07\x12\x16\n\x11\x44\x41Y_COUNT_30I_ACT\x10\xe4\x07\x12\x16\n\x11\x44\x41Y_COUNT_30M_360\x10\xe5\x07*b\n\x0cSwaptionType\x12\x1d\n\x19SWAPTION_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SWAPTION_TYPE_PAYER\x10\x01\x12\x1a\n\x16SWAPTION_TYPE_RECEIVER\x10\x02\x32\xf3\x02\n\x11StaticDataService\x12\xa3\x01\n\x06Search\x12\x42.systemathics.apis.services.static_data.v1.StaticDataSearchRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/staticdata\x12\xb7\x01\n\x10GetByIdentifiers\x12@.systemathics.apis.services.static_data.v1.StaticDataIdentifiers\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/staticdata/identifiersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EQUITYENTRY_MAPPINGENTRY']._options = None
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_EQUITYENTRY_SECTORSENTRY']._options = None
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_MAPPINGENTRY']._options = None
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_CATEGORYENTRY']._options = None
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_options = b'8\001'
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._options = None
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_STATICDATASERVICE'].methods_by_name['Search']._options = None
  _globals['_STATICDATASERVICE'].methods_by_name['Search']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/staticdata'
  _globals['_STATICDATASERVICE'].methods_by_name['GetByIdentifiers']._options = None
  _globals['_STATICDATASERVICE'].methods_by_name['GetByIdentifiers']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/staticdata/identifiers'
  _globals['_FREQUENCYTYPE']._serialized_start=8260
  _globals['_FREQUENCYTYPE']._serialized_end=8522
  _globals['_EXERCISETYPE']._serialized_start=8525
  _globals['_EXERCISETYPE']._serialized_end=8654
  _globals['_COUPONFREQUENCY']._serialized_start=8657
  _globals['_COUPONFREQUENCY']._serialized_end=8894
  _globals['_DAYCOUNT']._serialized_start=8897
  _globals['_DAYCOUNT']._serialized_end=11042
  _globals['_SWAPTIONTYPE']._serialized_start=11044
  _globals['_SWAPTIONTYPE']._serialized_end=11142
  _globals['_STATICDATASEARCHREQUEST']._serialized_start=319
  _globals['_STATICDATASEARCHREQUEST']._serialized_end=1949
  _globals['_STATICDATADATE']._serialized_start=1952
  _globals['_STATICDATADATE']._serialized_end=2108
  _globals['_STATICDATADATERANGE']._serialized_start=2111
  _globals['_STATICDATADATERANGE']._serialized_end=2250
  _globals['_STATICDATADOUBLE']._serialized_start=2253
  _globals['_STATICDATADOUBLE']._serialized_end=2394
  _globals['_STATICDATADOUBLERANGE']._serialized_start=2397
  _globals['_STATICDATADOUBLERANGE']._serialized_end=2560
  _globals['_STATICDATAINT']._serialized_start=2563
  _globals['_STATICDATAINT']._serialized_end=2698
  _globals['_STATICDATAINTRANGE']._serialized_start=2701
  _globals['_STATICDATAINTRANGE']._serialized_end=2859
  _globals['_STATICDATARESPONSE']._serialized_start=2862
  _globals['_STATICDATARESPONSE']._serialized_end=3131
  _globals['_CRYPTORESPONSE']._serialized_start=3134
  _globals['_CRYPTORESPONSE']._serialized_end=3263
  _globals['_EQUITYRESPONSE']._serialized_start=3266
  _globals['_EQUITYRESPONSE']._serialized_end=3395
  _globals['_FUTURERESPONSE']._serialized_start=3398
  _globals['_FUTURERESPONSE']._serialized_end=3527
  _globals['_EQUITYENTRY']._serialized_start=3530
  _globals['_EQUITYENTRY']._serialized_end=4994
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_start=4876
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_end=4934
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_start=4936
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_end=4994
  _globals['_FUTUREENTRY']._serialized_start=4997
  _globals['_FUTUREENTRY']._serialized_end=6490
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_start=4876
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_end=4934
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_start=6431
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_end=6490
  _globals['_CRYPTOENTRY']._serialized_start=6493
  _globals['_CRYPTOENTRY']._serialized_end=7937
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_start=4876
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_end=4934
  _globals['_STATICDATAIDENTIFIERS']._serialized_start=7939
  _globals['_STATICDATAIDENTIFIERS']._serialized_end=8061
  _globals['_STATICDATAIDENTIFIER']._serialized_start=8064
  _globals['_STATICDATAIDENTIFIER']._serialized_end=8203
  _globals['_TICKSIZE']._serialized_start=8205
  _globals['_TICKSIZE']._serialized_end=8257
  _globals['_STATICDATASERVICE']._serialized_start=11145
  _globals['_STATICDATASERVICE']._serialized_end=11516
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/option_type.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/option_type.proto\x12 systemathics.apis.type.shared.v1*T\n\nOptionType\x12\x1b\n\x17OPTION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10OPTION_TYPE_CALL\x10\x01\x12\x13\n\x0fOPTION_TYPE_PUT\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.option_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OPTIONTYPE']._serialized_start=88
  _globals['_OPTIONTYPE']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.calendar.v1 import calendar_pb2 as systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2


class CalendarServiceStub(object):
    """Called to request screener data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHolidayCode = channel.unary_stream(
                '/systemathics.apis.services.calendar.v1.CalendarService/GetHolidayCode',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayInfo.FromString,
                )
        self.HolidayCodeToMics = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/HolidayCodeToMics',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCodeToMicsResponse.FromString,
                )
        self.Holidays = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/Holidays',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysResponse.FromString,
                )
        self.TradingHoursMic = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/TradingHoursMic',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicResponse.FromString,
                )
        self.TradingHoursDates = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/TradingHoursDates',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursDateRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursDateResponse.FromString,
                )
        self.Mic = channel.unary_stream(
                '/systemathics.apis.services.calendar.v1.CalendarService/Mic',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.MicRecord.FromString,
                )
        self.TradingHours = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/TradingHours',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMessage.FromString,
                )


class CalendarServiceServicer(object):
    """Called to request screener data.
    """

    def GetHolidayCode(self, request, context):
        """Gets currencies with holidays information 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HolidayCodeToMics(self, request, context):
        """Gets mapping from holiday code to mic
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Holidays(self, request, context):
        """Gets holidays with code and year
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TradingHoursMic(self, request, context):
        """Gets mic code with trading hours information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TradingHoursDates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Mic(self, request, context):
        """Gets mic code with trading hours information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TradingHours(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CalendarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHolidayCode': grpc.unary_stream_rpc_method_handler(
                    servicer.GetHolidayCode,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayInfo.SerializeToString,
            ),
            'HolidayCodeToMics': grpc.unary_unary_rpc_method_handler(
                    servicer.HolidayCodeToMics,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCodeToMicsResponse.SerializeToString,
            ),
            'Holidays': grpc.unary_unary_rpc_method_handler(
                    servicer.Holidays,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysResponse.SerializeToString,
            ),
            'TradingHoursMic': grpc.unary_unary_rpc_method_handler(
                    servicer.TradingHoursMic,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicResponse.SerializeToString,
            ),
            'TradingHoursDates': grpc.unary_unary_rpc_method_handler(
                    servicer.TradingHoursDates,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursDateRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursDateResponse.SerializeToString,
            ),
            'Mic': grpc.unary_stream_rpc_method_handler(
                    servicer.Mic,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.MicRecord.SerializeToString,
            ),
            'TradingHours': grpc.unary_unary_rpc_method_handler(
                    servicer.TradingHours,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.calendar.v1.CalendarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CalendarService(object):
    """Called to request screener data.
    """

    @staticmethod
    def GetHolidayCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/GetHolidayCode',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HolidayCodeToMics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/HolidayCodeToMics',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCodeToMicsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Holidays(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/Holidays',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TradingHoursMic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/TradingHoursMic',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TradingHoursDates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/TradingHoursDates',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursDateRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursDateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Mic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/Mic',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.MicRecord.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TradingHours(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/TradingHours',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/calendar/v1/trading_hours.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.calendar.v1 import calendar_pb2 as systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/services/calendar/v1/trading_hours.proto\x12&systemathics.apis.services.calendar.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x35systemathics/apis/services/calendar/v1/calendar.proto\"z\n\x16SetTradingHoursRequest\x12`\n\rtrading_hours\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.calendar.v1.TradingHoursMessageR\x0ctradingHours2\xa5\x01\n\x13TradingHoursService\x12\x8d\x01\n\x0fSetTradingHours\x12>.systemathics.apis.services.calendar.v1.SetTradingHoursRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/calendar/trading_hoursb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.calendar.v1.trading_hours_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRADINGHOURSSERVICE'].methods_by_name['SetTradingHours']._options = None
  _globals['_TRADINGHOURSSERVICE'].methods_by_name['SetTradingHours']._serialized_options = b'\202\323\344\223\002\034\"\032/v1/calendar/trading_hours'
  _globals['_SETTRADINGHOURSREQUEST']._serialized_start=216
  _globals['_SETTRADINGHOURSREQUEST']._serialized_end=338
  _globals['_TRADINGHOURSSERVICE']._serialized_start=341
  _globals['_TRADINGHOURSSERVICE']._serialized_end=506
# @@protoc_insertion_point(module_scope)
